import os
import sys
import getopt
import importlib

class Matest(object):
    plugins = {}

    @classmethod
    def init(cls):
        cls.path = os.path.join(os.path.dirname(os.path.abspath(__file__)), 'plugin')
        # [cls.load_plugin(m) for m in os.listdir(path) if m.endswith('.py')]

    @classmethod
    def load_plugin(cls, m):
        pass
        # _m = importlib.import_module(f'plugin.{m[:-3]}')

    @classmethod
    def run(cls, argv):
        print(f'Hello world: {argv}')


if __name__ == '__main__':
    Matest.Run(sys.argv[1:])



from setuptools import setup, find_packages

setup(
    name = "matest",
    version = "0.0.1",
    keywords = ("mate", "test", "matest"),
    description = "mate test",
    long_description = "mate test tools",
    license = "MIT Licence",

    url = "https://github.com/matest",
    author = "matest",
    author_email = "erenjian@qq.com",

    packages = find_packages(),
    include_package_data = True,
    platforms = "any",
    install_requires = ["numpy", "pandas"]
)